@@ -39,5 +39,5 @@ data_info <- function(landscape){
                         yes = "integer",
                         no = "non-integer"))
 
-    tibble::tibble(class = class, n_classes = length(landscape_values))
+    tibble::new_tibble(list(class = class, n_classes = length(landscape_values)))
 }
