@@ -2,7 +2,7 @@
 #'
 #' @description Fast calculation of adjacencies between classes in a raster
 #'
-#' @param landscape Raster* Layer, Stack, Brick, SpatRaster (terra), stars, or a list of rasterLayers.
+#' @param landscape A categorical raster object: SpatRaster; Raster* Layer, Stack, Brick; stars or a list of SpatRasters.
 #' @param neighbourhood The number of directions in which cell adjacencies are
 #' considered as neighbours: 4 (rook's case), 8 (queen's case) or a binary matrix
 #'  where the ones define the neighbourhood. The default is 4.
@@ -26,19 +26,21 @@
 #' @return matrix with adjacencies between classes in a raster and between cells from the same class.
 #'
 #' @examples
+#' landscape <- terra::rast(landscapemetrics::landscape)
 #' # calculate full adjacency matrix
 #' get_adjacencies(landscape, 4)
 #'
+#' # equivalent with the terra package:
+#' adjacencies <- terra::adjacent(landscape, 1:terra::ncell(landscape), "rook", pairs = TRUE)
+#' table(terra::values(landscape, mat = FALSE)[adjacencies[,1]],
+#' terra::values(landscape, mat = FALSE)[adjacencies[,2]])
+#'
 #' # count diagonal neighbour adjacencies
 #' diagonal_matrix <- matrix(c(1,  NA,  1,
 #'                             NA,  0, NA,
 #'                             1,  NA,  1), 3, 3, byrow = TRUE)
 #' get_adjacencies(landscape, diagonal_matrix)
 #'
-#' # equivalent with the raster package:
-#' adjacencies <- raster::adjacent(landscape, 1:raster::ncell(landscape), 4, pairs=TRUE)
-#' table(landscape[adjacencies[,1]], landscape[adjacencies[,2]])
-#'
 #' @aliases get_adjacencies
 #' @rdname get_adjacencies
 #'
@@ -70,7 +72,7 @@ get_adjacencies_internal <- function(landscape,
 
     # convert to matrix
     if (!inherits(x = landscape, what = "matrix")) {
-        landscape <- raster::as.matrix(landscape)
+        landscape <- terra::as.matrix(landscape, wide = TRUE)
     }
 
     adjacencies <- rcpp_get_coocurrence_matrix(landscape,
