@@ -66,29 +66,31 @@ lsm_c_cai_mn <- function(landscape, directions = 8, consider_boundary = FALSE, e
     tibble::add_column(result, layer, .before = TRUE)
 }
 
-lsm_c_cai_mn_calc <- function(landscape, directions, consider_boundary, edge_depth){
+lsm_c_cai_mn_calc <- function(landscape, directions, consider_boundary, edge_depth, resolution, extras = NULL){
 
     # calculate core area index for each patch
     cai <- lsm_p_cai_calc(landscape,
                           directions = directions,
                           consider_boundary = consider_boundary,
-                          edge_depth = edge_depth)
+                          edge_depth = edge_depth,
+                          resolution = resolution,
+                          extras = extras)
 
     # all values NA
     if (all(is.na(cai$value))) {
-        return(tibble::tibble(level = "class",
+        return(tibble::new_tibble(list(level = "class",
                               class = as.integer(NA),
                               id = as.integer(NA),
                               metric = "cai_mn",
-                              value = as.double(NA)))
+                              value = as.double(NA))))
     }
 
     # summarise for each class
     cai_mean <- stats::aggregate(x = cai[, 5], by = cai[, 2], FUN = mean)
 
-    return(tibble::tibble(level = "class",
+    return(tibble::new_tibble(list(level = rep("class", nrow(cai_mean)),
                           class = as.integer(cai_mean$class),
-                          id = as.integer(NA),
-                          metric = "cai_mn",
-                          value = as.double(cai_mean$value)))
+                          id = rep(as.integer(NA), nrow(cai_mean)),
+                          metric = rep("cai_mn", nrow(cai_mean)),
+                          value = as.double(cai_mean$value))))
 }
