@@ -63,27 +63,30 @@ lsm_c_frac_cv <- function(landscape, directions = 8) {
     tibble::add_column(result, layer, .before = TRUE)
 }
 
-lsm_c_frac_cv_calc <- function(landscape, directions, resolution = NULL){
+lsm_c_frac_cv_calc <- function(landscape, directions, resolution, extras = NULL){
 
     frac <- lsm_p_frac_calc(landscape,
                             directions = directions,
-                            resolution = resolution)
+                            resolution = resolution,
+                            extras = extras)
 
     # all cells are NA
     if (all(is.na(frac$value))) {
-        return(tibble::tibble(level = "class",
+        return(tibble::new_tibble(list(level = "class",
                               class = as.integer(NA),
                               id = as.integer(NA),
                               metric = "frac_cv",
-                              value = as.double(NA)))
+                              value = as.double(NA))))
     }
 
     frac_cv <- stats::aggregate(x = frac[, 5], by = frac[, 2],
                                 FUN = function(x) stats::sd(x) / mean(x) * 100)
 
-    return(tibble::tibble(level = "class",
-                          class = as.integer(frac_cv$class),
-                          id = as.integer(NA),
-                          metric = "frac_cv",
-                          value = as.double(frac_cv$value)))
+    return(tibble::new_tibble(list(
+        level = rep("class", nrow(frac_cv)),
+        class = as.integer(frac_cv$class),
+        id = rep(as.integer(NA), nrow(frac_cv)),
+        metric = rep("frac_cv", nrow(frac_cv)),
+        value = as.double(frac_cv$value)
+    )))
 }
