@@ -61,26 +61,29 @@ lsm_c_frac_mn <- function(landscape, directions = 8) {
     tibble::add_column(result, layer, .before = TRUE)
 }
 
-lsm_c_frac_mn_calc <- function(landscape, directions, resolution = NULL){
+lsm_c_frac_mn_calc <- function(landscape, directions, resolution, extras = NULL){
 
     frac <- lsm_p_frac_calc(landscape,
                             directions = directions,
-                            resolution = resolution)
+                            resolution = resolution,
+                            extras = extras)
 
     # all cells are NA
     if (all(is.na(frac$value))) {
-        return(tibble::tibble(level = "class",
+        return(tibble::new_tibble(list(level = "class",
                               class = as.integer(NA),
                               id = as.integer(NA),
                               metric = "frac_mn",
-                              value = as.double(NA)))
+                              value = as.double(NA))))
     }
 
     frac_mean <- stats::aggregate(x = frac[, 5], by = frac[, 2], FUN = mean)
 
-    return(tibble::tibble(level = "class",
-                          class = as.integer(frac_mean$class),
-                          id = as.integer(NA),
-                          metric = "frac_mn",
-                          value = as.double(frac_mean$value)))
+    return(tibble::new_tibble(list(
+        level = rep("class", nrow(frac_mean)),
+        class = as.integer(frac_mean$class),
+        id = rep(as.integer(NA), nrow(frac_mean)),
+        metric = rep("frac_mn", nrow(frac_mean)),
+        value = as.double(frac_mean$value)
+    )))
 }
