@@ -58,7 +58,7 @@ lsm_c_iji <- function(landscape, verbose = TRUE) {
     tibble::add_column(result, layer, .before = TRUE)
 }
 
-lsm_c_iji_calc <- function(landscape, verbose) {
+lsm_c_iji_calc <- function(landscape, verbose, extras = NULL) {
 
     # conver to matrix
     if (!inherits(x = landscape, what = "matrix")) {
@@ -67,15 +67,18 @@ lsm_c_iji_calc <- function(landscape, verbose) {
 
     # all cells are NA
     if (all(is.na(landscape))) {
-        return(tibble::tibble(level = "class",
+        return(tibble::new_tibble(list(level = "class",
                               class = as.integer(NA),
                               id = as.integer(NA),
                               metric = "iji",
-                              value = as.double(NA)))
+                              value = as.double(NA))))
     }
 
-    adjacencies <- rcpp_get_coocurrence_matrix(landscape,
-                                               as.matrix(4))
+    if (!is.null(extras)){
+        adjacencies <- extras$neighbor_matrix
+    } else {
+        adjacencies <- rcpp_get_coocurrence_matrix(landscape, as.matrix(4))
+    }
 
     classes <- rownames(adjacencies)
 
@@ -85,11 +88,11 @@ lsm_c_iji_calc <- function(landscape, verbose) {
             warning("Number of classes must be >= 3, IJI = NA.", call. = FALSE)
         }
 
-        return(tibble::tibble(level = "class",
+        return(tibble::new_tibble(list(level = rep("class", length(classes)),
                               class = as.integer(classes),
-                              id = as.integer(NA),
-                              metric = "iji",
-                              value = as.double(NA)))
+                              id = rep(as.integer(NA), length(classes)),
+                              metric = rep("iji", length(classes)),
+                              value = rep(as.double(NA), length(classes)))))
     }
 
     else {
@@ -103,10 +106,12 @@ lsm_c_iji_calc <- function(landscape, verbose) {
 
         iji <- (class_sums / log(ncol(adjacencies) - 1)) * 100
 
-        return(tibble::tibble(level = "class",
-                              class = as.integer(classes),
-                              id = as.integer(NA),
-                              metric = "iji",
-                              value = as.double(iji)))
+        return(tibble::new_tibble(list(
+            level = rep("class", length(iji)),
+            class = as.integer(classes),
+            id = rep(as.integer(NA), length(iji)),
+            metric = rep("iji", length(iji)),
+            value = as.double(iji)
+        )))
     }
 }
