@@ -65,31 +65,31 @@ lsm_c_ndca <- function(landscape, directions = 8, consider_boundary = FALSE, edg
     tibble::add_column(result, layer, .before = TRUE)
 }
 
-lsm_c_ndca_calc <- function(landscape, directions, consider_boundary, edge_depth,
-                            points = NULL){
+lsm_c_ndca_calc <- function(landscape, directions, consider_boundary, edge_depth, resolution, extras = NULL){
 
     # get number of core areas for each patch
     ndca <- lsm_p_ncore_calc(landscape,
                              directions = directions,
                              consider_boundary = consider_boundary,
                              edge_depth = edge_depth,
-                             points = points)
+                             resolution = resolution,
+                             extras = extras)
 
     # all cells are NA
     if (all(is.na(ndca$value))) {
-        return(tibble::tibble(level = "class",
+        return(tibble::new_tibble(list(level = "class",
                               class = as.integer(NA),
                               id = as.integer(NA),
                               metric = "ndca",
-                              value = as.double(NA)))
+                              value = as.double(NA))))
     }
 
     # summarise for each class
     ndca <- stats::aggregate(x = ndca[, 5], by = ndca[, 2], FUN = sum)
 
-    return(tibble::tibble(level = "class",
-                          class = as.integer(ndca$class),
-                          id = as.integer(NA),
-                          metric = "ndca",
-                          value = as.double(ndca$value)))
+    return(tibble::new_tibble(list(level = rep("class", nrow(ndca)),
+                              class = as.integer(ndca$class),
+                              id = rep(as.integer(NA), nrow(ndca)),
+                              metric = rep("ndca", nrow(ndca)),
+                              value = as.double(ndca$value))))
 }
