@@ -64,39 +64,44 @@ lsm_c_pafrac <- function(landscape, directions = 8, verbose = TRUE) {
     tibble::add_column(result, layer, .before = TRUE)
 }
 
-lsm_c_pafrac_calc <- function(landscape, directions, verbose, resolution = NULL){
+lsm_c_pafrac_calc <- function(landscape, directions, verbose, resolution, extras = NULL){
 
-    # convert to matrix
-    if (!inherits(x = landscape, what = "matrix")) {
-        resolution <- terra::res(landscape)
+    if (missing(resolution)) resolution <- terra::res(landscape)
 
+    if (is.null(extras)){
+        metrics <- "lsm_c_pafrac"
         landscape <- terra::as.matrix(landscape, wide = TRUE)
+        extras <- prepare_extras(metrics, landscape_mat = landscape,
+                                            directions = directions, resolution = resolution)
     }
 
     # all values NA
     if (all(is.na(landscape))) {
-        return(tibble::tibble(level = "class",
+        return(tibble::new_tibble(list(level = "class",
                               class = as.integer(NA),
                               id = as.integer(NA),
                               metric = "pafrac",
-                              value = as.double(NA)))
+                              value = as.double(NA))))
     }
 
     # get patch area in sqm
     area_patch <- lsm_p_area_calc(landscape,
                                   directions = directions,
-                                  resolution = resolution)
+                                  resolution = resolution,
+                                  extras = extras)
 
     area_patch$value <- area_patch$value * 10000
 
     # get patch perimeter
     perimeter_patch <- lsm_p_perim_calc(landscape,
                                         directions = directions,
-                                        resolution = resolution)
+                                        resolution = resolution,
+                                        extras = extras)
 
     # get number of patches
     np_class <- lsm_c_np_calc(landscape,
-                              directions = directions)
+                              directions = directions,
+                              extras = extras)
 
     pafrac_class <- lapply(X = seq_len(nrow(np_class)), FUN = function(class_current) {
 
@@ -122,12 +127,12 @@ lsm_c_pafrac_calc <- function(landscape, directions, verbose, resolution = NULL)
             pafrac <- 2 / regression_model_class$coefficients[[2]]
         }
 
-        tibble::tibble(
-            level = "class",
-            class = as.integer(class_name),
-            id = as.integer(NA),
-            metric = "pafrac",
-            value = as.double(pafrac))
+        tibble::new_tibble(list(
+            level = rep("class", length(pafrac)),
+            class = rep(as.integer(class_name), length(pafrac)),
+            id = rep(as.integer(NA), length(pafrac)),
+            metric = rep("pafrac", length(pafrac)),
+            value = as.double(pafrac)))
         })
 
     do.call("rbind", pafrac_class)
