@@ -61,20 +61,21 @@ lsm_c_shape_sd <- function(landscape, directions = 8) {
     tibble::add_column(result, layer, .before = TRUE)
 }
 
-lsm_c_shape_sd_calc <- function(landscape, directions, resolution = NULL){
+lsm_c_shape_sd_calc <- function(landscape, directions, resolution, extras = NULL){
 
     # shape index for each patch
     shape <- lsm_p_shape_calc(landscape,
                               directions = directions,
-                              resolution = resolution)
+                              resolution = resolution,
+                              extras = extras)
 
     # all cells are NA
     if (all(is.na(shape$value))) {
-        return(tibble::tibble(level = "class",
+        return(tibble::new_tibble(list(level = "class",
                               class = as.integer(NA),
                               id = as.integer(NA),
                               metric = "shape_sd",
-                              value = as.double(NA)))
+                              value = as.double(NA))))
     }
 
     # calculate sd
@@ -82,9 +83,9 @@ lsm_c_shape_sd_calc <- function(landscape, directions, resolution = NULL){
                                  FUN = stats::sd,
                                  na.rm = TRUE)
 
-    return(tibble::tibble(level = "class",
-                          class = as.integer(shape_sd$class),
-                          id = as.integer(NA),
-                          metric = "shape_sd",
-                          value = as.double(shape_sd$value)))
+    return(tibble::new_tibble(list(level = rep("class", nrow(shape_sd)),
+                              class = as.integer(shape_sd$class),
+                              id = rep(as.integer(NA), nrow(shape_sd)),
+                              metric = rep("shape_sd", nrow(shape_sd)),
+                              value = as.double(shape_sd$value))))
 }
