@@ -70,25 +70,26 @@ lsm_l_contig_mn <- function(landscape, directions = 8) {
     tibble::add_column(result, layer, .before = TRUE)
 }
 
-lsm_l_contig_mn_calc <- function(landscape, directions) {
+lsm_l_contig_mn_calc <- function(landscape, directions, extras = NULL) {
 
     contig_patch <- lsm_p_contig_calc(landscape,
-                                      directions = directions)
+                                      directions = directions,
+                                      extras = extras)
 
     # all values NA
     if (all(is.na(contig_patch$value))) {
-        return(tibble::tibble(level = "landscape",
+        return(tibble::new_tibble(list(level = "landscape",
                               class = as.integer(NA),
                               id = as.integer(NA),
                               metric = "contig_mn",
-                              value = as.double(NA)))
+                              value = as.double(NA))))
     }
 
     contig_mn <- mean(contig_patch$value)
 
-    return(tibble::tibble(level = "landscape",
-                          class = as.integer(NA),
-                          id = as.integer(NA),
-                          metric = "contig_mn",
-                          value = as.double(contig_mn)))
+    return(tibble::new_tibble(list(level = rep("landscape", length(contig_mn)),
+                 class = rep(as.integer(NA), length(contig_mn)),
+                 id = rep(as.integer(NA), length(contig_mn)),
+                 metric = rep("contig_mn", length(contig_mn)),
+                 value = as.double(contig_mn))))
 }
