@@ -58,23 +58,24 @@ lsm_l_division <- function(landscape, directions = 8) {
     tibble::add_column(result, layer, .before = TRUE)
 }
 
-lsm_l_division_calc <- function(landscape, directions, resolution = NULL) {
+lsm_l_division_calc <- function(landscape, directions, resolution, extras = NULL) {
 
     # get patch area
     area_patch <- lsm_p_area_calc(landscape,
                                   directions = directions,
-                                  resolution = resolution)
+                                  resolution = resolution,
+                                  extras = extras)
 
     # summarise to total area
     area_total <- sum(area_patch$value)
 
     # all values NA
     if (is.na(area_total)) {
-        return(tibble::tibble(level = "landscape",
+        return(tibble::new_tibble(list(level = "landscape",
                               class = as.integer(NA),
                               id = as.integer(NA),
                               metric = "division",
-                              value = as.double(NA)))
+                              value = as.double(NA))))
     }
 
     # divison for each patch
@@ -83,9 +84,9 @@ lsm_l_division_calc <- function(landscape, directions, resolution = NULL) {
     # summarise for whole landscape
     division <- 1 - sum(area_patch$value)
 
-    return(tibble::tibble(level = "landscape",
-                          class = as.integer(NA),
-                          id = as.integer(NA),
-                          metric = "division",
-                          value = as.double(division)))
+    return(tibble::new_tibble(list(level = rep("landscape", length(division)),
+                 class = rep(as.integer(NA), length(division)),
+                 id = rep(as.integer(NA), length(division)),
+                 metric = rep("division", length(division)),
+                 value = as.double(division))))
 }
