@@ -71,28 +71,28 @@ lsm_l_gyrate_mn <- function(landscape,
     tibble::add_column(result, layer, .before = TRUE)
 }
 
-lsm_l_gyrate_mn_calc <- function(landscape, directions, cell_center,
-                                 points = NULL) {
+lsm_l_gyrate_mn_calc <- function(landscape, directions, cell_center, resolution, extras = NULL) {
 
     gyrate_patch <- lsm_p_gyrate_calc(landscape,
                                       directions = directions,
                                       cell_center = cell_center,
-                                      points = points)
+                                      resolution = resolution,
+                                      extras = extras)
 
     # all values NA
     if (all(is.na(gyrate_patch$value))) {
-        return(tibble::tibble(level = "landscape",
+        return(tibble::new_tibble(list(level = "landscape",
                               class = as.integer(NA),
                               id = as.integer(NA),
                               metric = "gyrate_mn",
-                              value = as.double(NA)))
+                              value = as.double(NA))))
     }
 
     gyrate_mn <- mean(gyrate_patch$value)
 
-    return(tibble::tibble(level = "landscape",
-                          class = as.integer(NA),
-                          id = as.integer(NA),
-                          metric = "gyrate_mn",
-                          value = as.double(gyrate_mn)))
+    return(tibble::new_tibble(list(level = rep("landscape", length(gyrate_mn)),
+                 class = rep(as.integer(NA), length(gyrate_mn)),
+                 id = rep(as.integer(NA), length(gyrate_mn)),
+                 metric = rep("gyrate_mn", length(gyrate_mn)),
+                 value = as.double(gyrate_mn))))
 }
