@@ -60,31 +60,32 @@ lsm_l_mesh <- function(landscape, directions = 8) {
     tibble::add_column(result, layer, .before = TRUE)
 }
 
-lsm_l_mesh_calc <- function(landscape, directions, resolution = NULL) {
+lsm_l_mesh_calc <- function(landscape, directions, resolution, extras = NULL) {
 
     # get patch area
     area_patch <- lsm_p_area_calc(landscape,
                                   directions = directions,
-                                  resolution = resolution)
+                                  resolution = resolution,
+                                  extras = extras)
 
     # summarise to total area
     area_total <- sum(area_patch$value)
 
     # all values NA
     if (is.na(area_total)) {
-        return(tibble::tibble(level = "landscape",
+        return(tibble::new_tibble(list(level = "landscape",
                               class = as.integer(NA),
                               id = as.integer(NA),
                               metric = "mesh",
-                              value = as.double(NA)))
+                              value = as.double(NA))))
     }
 
     # calculate mesh first take area ^ 2, than sum for whole landscape divided by landscape area total
     mesh <- sum(area_patch$value ^ 2) / area_total
 
-    return(tibble::tibble(level = "landscape",
-                          class = as.integer(NA),
-                          id = as.integer(NA),
-                          metric = "mesh",
-                          value = as.double(mesh)))
+    return(tibble::new_tibble(list(level = rep("landscape", length(mesh)),
+                class = rep(as.integer(NA), length(mesh)),
+                id = rep(as.integer(NA), length(mesh)),
+                metric = rep("mesh", length(mesh)),
+                value = as.double(mesh))))
 }
