@@ -54,19 +54,20 @@ lsm_l_msiei <- function(landscape, directions = 8) {
     tibble::add_column(result, layer, .before = TRUE)
 }
 
-lsm_l_msiei_calc <- function(landscape, directions, resolution = NULL) {
+lsm_l_msiei_calc <- function(landscape, directions, resolution, extras = NULL) {
 
     patch_area <- lsm_p_area_calc(landscape,
                                   directions = directions,
-                                  resolution = resolution)
+                                  resolution = resolution,
+                                  extras = extras)
 
     # all values NA
     if (all(is.na(patch_area$value))) {
-        return(tibble::tibble(level = "landscape",
+        return(tibble::new_tibble(list(level = "landscape",
                               class = as.integer(NA),
                               id = as.integer(NA),
                               metric = "msiei",
-                              value = as.double(NA)))
+                              value = as.double(NA))))
     }
 
     msidi <- stats::aggregate(x = patch_area[, 5], by = patch_area[, 2],
@@ -74,13 +75,18 @@ lsm_l_msiei_calc <- function(landscape, directions, resolution = NULL) {
 
     msidi <- -log(sum((msidi$value / sum(msidi$value)) ^ 2))
 
-    pr <- length(get_unique_values_int(landscape, verbose = FALSE))
+    if (!is.null(extras)){
+        classes <- extras$classes
+    } else {
+        classes <- get_unique_values_int(landscape, verbose = FALSE)
+    }
+    pr <- length(classes)
 
     msiei <- msidi / log(pr)
 
-    return(tibble::tibble(level = "landscape",
-                          class = as.integer(NA),
-                          id = as.integer(NA),
-                          metric = "msiei",
-                          value = as.double(msiei)))
+    return(tibble::new_tibble(list(level = rep("landscape", length(msiei)),
+                          class = rep(as.integer(NA), length(msiei)),
+                          id = rep(as.integer(NA), length(msiei)),
+                          metric = rep("msiei", length(msiei)),
+                          value = as.double(msiei))))
 }
