@@ -46,22 +46,27 @@ lsm_l_pr <- function(landscape){
     tibble::add_column(result, layer, .before = TRUE)
 }
 
-lsm_l_pr_calc <- function(landscape){
+lsm_l_pr_calc <- function(landscape, extras = NULL){
 
-    richness <- length(get_unique_values_int(landscape, verbose = FALSE))
+    if (!is.null(extras)){
+        classes <- extras$classes
+    } else {
+        classes <- get_unique_values_int(landscape, verbose = FALSE)
+    }
+    richness <- length(classes)
 
     # all values NA
     if (richness == 0) {
-        return(tibble::tibble(level = "landscape",
+        return(tibble::new_tibble(list(level = "landscape",
                               class = as.integer(NA),
                               id = as.integer(NA),
                               metric = "pr",
-                              value = as.double(NA)))
+                              value = as.double(NA))))
     }
 
-    return(tibble::tibble(level = "landscape",
-                          class = as.integer(NA),
-                          id = as.integer(NA),
-                          metric = "pr",
-                          value = as.double(richness)))
+    return(tibble::new_tibble(list(level = rep("landscape", length(richness)),
+                          class = rep(as.integer(NA), length(richness)),
+                          id = rep(as.integer(NA), length(richness)),
+                          metric = rep("pr", length(richness)),
+                          value = as.double(richness))))
 }
