@@ -60,28 +60,29 @@ lsm_l_shape_cv <- function(landscape, directions = 8) {
     tibble::add_column(result, layer, .before = TRUE)
 }
 
-lsm_l_shape_cv_calc <- function(landscape, directions, resolution = NULL){
+lsm_l_shape_cv_calc <- function(landscape, directions, resolution, extras = NULL){
 
     # shape index for each patch
     shape <- lsm_p_shape_calc(landscape,
                               directions = directions,
-                              resolution = resolution)
+                              resolution = resolution,
+                              extras = extras)
 
     # all values NA
     if (all(is.na(shape$value))) {
-        return(tibble::tibble(level = "landscape",
+        return(tibble::new_tibble(list(level = "landscape",
                               class = as.integer(NA),
                               id = as.integer(NA),
                               metric = "shape_cv",
-                              value = as.double(NA)))
+                              value = as.double(NA))))
     }
 
     # calculate cv
     shape_cv <- stats::sd(shape$value, na.rm = TRUE) / mean(shape$value, na.rm = TRUE) * 100
 
-    return(tibble::tibble(level = "landscape",
-                          class = as.integer(NA),
-                          id = as.integer(NA),
-                          metric = "shape_cv",
-                          value = as.double(shape_cv)))
+    return(tibble::new_tibble(list(level = rep("landscape", length(shape_cv)),
+                          class = rep(as.integer(NA), length(shape_cv)),
+                          id = rep(as.integer(NA), length(shape_cv)),
+                          metric = rep("shape_cv", length(shape_cv)),
+                          value = as.double(shape_cv))))
 }
