@@ -54,20 +54,21 @@ lsm_l_shei <- function(landscape){
     tibble::add_column(result, layer, .before = TRUE)
 }
 
-lsm_l_shei_calc <- function(landscape, resolution = NULL){
+lsm_l_shei_calc <- function(landscape, resolution, extras = NULL){
 
     # get class proportions (direction doesn't matter)
     prop <- lsm_c_pland_calc(landscape,
                              directions = 8,
-                             resolution = resolution)
+                             resolution = resolution,
+                             extras = extras)
 
     # all values NA
     if (all(is.na(prop$value))) {
-        return(tibble::tibble(level = "landscape",
+        return(tibble::new_tibble(list(level = "landscape",
                               class = as.integer(NA),
                               id = as.integer(NA),
                               metric = "shei",
-                              value = as.double(NA)))
+                              value = as.double(NA))))
     }
 
     prop <- prop$value / 100
@@ -78,9 +79,9 @@ lsm_l_shei_calc <- function(landscape, resolution = NULL){
         shei <- -sum(prop * log(prop)) / log(length(prop))
     }
 
-    return(tibble::tibble(level = "landscape",
-                          class = as.integer(NA),
-                          id = as.integer(NA),
-                          metric = "shei",
-                          value = as.double(shei)))
+    return(tibble::new_tibble(list(level = rep("landscape", length(shei)),
+                          class = rep(as.integer(NA), length(shei)),
+                          id = rep(as.integer(NA), length(shei)),
+                          metric = rep("shei", length(shei)),
+                          value = as.double(shei))))
 }
