@@ -72,7 +72,7 @@ lsm_p_contig <- function(landscape, directions = 8) {
     tibble::add_column(result, layer, .before = TRUE)
 }
 
-lsm_p_contig_calc <- function(landscape, directions) {
+lsm_p_contig_calc <- function(landscape, directions, extras = NULL) {
 
     # convert to matrix
     if (!inherits(x = landscape, what = "matrix")) {
@@ -81,15 +81,21 @@ lsm_p_contig_calc <- function(landscape, directions) {
 
     # all values NA
     if (all(is.na(landscape))) {
-        return(tibble::tibble(level = "patch",
+        return(tibble::new_tibble(list(level = "patch",
                               class = as.integer(NA),
                               id = as.integer(NA),
                               metric = "contig",
-                              value = as.double(NA)))
+                              value = as.double(NA))))
     }
 
     # get unique values
-    classes <- get_unique_values_int(landscape, verbose = FALSE)
+    if (!is.null(extras)){
+        classes <- extras$classes
+        class_patches <- extras$class_patches
+    } else {
+        classes <- get_unique_values_int(landscape, verbose = FALSE)
+        class_patches <- get_class_patches(landscape, classes, directions)
+    }
 
     # diagonal neighbours
     diagonal_matrix <- matrix(c(1, NA, 1,
@@ -105,9 +111,7 @@ lsm_p_contig_calc <- function(landscape, directions) {
                             lapply(classes, function(patches_class) {
 
         # get connected patches
-        patch_mat <- get_patches_int(landscape,
-                                     directions = directions,
-                                     class = patches_class)[[1]]
+        patch_mat <- class_patches[[as.character(patches_class)]]
 
         # get number of cells for each patch
         n_cells <- rcpp_get_composition_vector(patch_mat)
@@ -115,7 +119,6 @@ lsm_p_contig_calc <- function(landscape, directions) {
         # get number of patches
         n_patches <- length(n_cells)
 
-
         # get diagonal neighbours of same patch
         diagonal_neighbours <- rcpp_get_coocurrence_matrix_diag(patch_mat,
                                                                 directions = as.matrix(diagonal_matrix))
@@ -130,20 +133,20 @@ lsm_p_contig_calc <- function(landscape, directions) {
 
         class <- patches_class
 
-        rm(patch_mat)
-        gc(verbose = FALSE)
+        #rm(patch_mat)
+        #gc(verbose = FALSE)
 
-        tibble::tibble(class = class,
-                       value = contiguity)
+        tibble::new_tibble(list(class = rep(class, length(contiguity)),
+                                value = contiguity))
 
         })
     )
 
-    tibble::tibble(
-        level = "patch",
+    tibble::new_tibble(list(
+        level = rep("patch", nrow(contig_patch)),
         class = as.integer(contig_patch$class),
         id = as.integer(seq_len(nrow(contig_patch))),
-        metric = "contig",
+        metric = rep("contig", nrow(contig_patch)),
         value = as.double(contig_patch$value)
-    )
+    ))
 }
