@@ -68,61 +68,63 @@ lsm_p_gyrate <- function(landscape, directions = 8,
     tibble::add_column(result, layer, .before = TRUE)
 }
 
-lsm_p_gyrate_calc <- function(landscape, directions, cell_center,
-                              points = NULL) {
+lsm_p_gyrate_calc <- function(landscape, directions, cell_center, resolution, extras = NULL) {
 
-    # conver to matrix
+    if (missing(resolution)) resolution <- terra::res(landscape)
+
+    # convert to matrix
     if (!inherits(x = landscape, what = "matrix")) {
-
-        # get coordinates and values of all cells
-        points <- raster_to_points(landscape)[, 2:4]
-
-        # convert to matrix
         landscape <- terra::as.matrix(landscape, wide = TRUE)
     }
 
     # all values NA
     if (all(is.na(landscape))) {
-        return(tibble::tibble(level = "patch",
+        return(tibble::new_tibble(list(level = "patch",
                               class = as.integer(NA),
                               id = as.integer(NA),
                               metric = "gyrate",
-                              value = as.double(NA)))
+                              value = as.double(NA))))
     }
 
-    # get uniuqe class id
-    classes <- get_unique_values_int(landscape, verbose = FALSE)
+    # get unique class id
+    if (!is.null(extras)){
+        classes <- extras$classes
+        class_patches <- extras$class_patches
+        points <- extras$points
+    } else {
+        classes <- get_unique_values_int(landscape, verbose = FALSE)
+        class_patches <- get_class_patches(landscape, classes, directions)
+        points <- get_points(landscape, resolution)
+    }
 
     gyrate <- do.call(rbind,
                       lapply(classes, function(patches_class) {
 
         # get connected patches
-        landscape_labeled <- get_patches_int(landscape,
-                                         class = patches_class,
-                                         directions = directions)[[1]]
+        landscape_labeled <- class_patches[[as.character(patches_class)]]
 
         # transpose to get same direction of ID
         landscape_labeled <- t(landscape_labeled)
 
-        # get coordinates of current class
-        points <- matrix(points[which(!is.na(landscape_labeled)), ],
-                         ncol = 3)
+        # get (relative) coordinates of current class
+        points <- which(!is.na(landscape_labeled), arr.ind = TRUE)
+        points <- mapply(FUN = `*`, as.data.frame(points), resolution)
 
         # set ID from class ID to unique patch ID
-        points[, 3] <- landscape_labeled[!is.na(landscape_labeled)]
+        points <- cbind(points, landscape_labeled[!is.na(landscape_labeled)])
 
-        # # conver to tibble
+        # # convert to tibble
         points <- stats::setNames(object = data.frame(points),
                                   nm = c("x", "y", "id"))
 
-        # calcuale the centroid of each patch (mean of all coords)
+        # calculate the centroid of each patch (mean of all coords)
         centroid <- stats::aggregate(points[, c(1, 2)],
                                      by = list(id = points[, 3]),
                                      FUN = mean)
 
         # create full data set with raster-points and patch centroids
         full_data <- merge(x = points, y = centroid, by = "id",
-                           suffixes = c("","_centroid"))
+                           suffixes = c("", "_centroid"))
 
         # calculate distance from each cell center to centroid
         full_data$dist <- sqrt((full_data$x - full_data$x_centroid) ^ 2 +
@@ -135,7 +137,7 @@ lsm_p_gyrate_calc <- function(landscape, directions, cell_center,
             centroid <- do.call(rbind, by(data = full_data,
                                           INDICES = full_data[, 1],
                                           FUN = function(x)
-                                              x[x$dist == min(x$dist), ]))[, c(1, 2, 3)]
+                                          x[which(signif(x$dist) == min(signif(x$dist))), ]))[, c(1, 2, 3)]
 
             # create full data set with raster-points and patch centroids
             full_data <- merge(x = points, y = centroid, by = "id",
@@ -157,10 +159,10 @@ lsm_p_gyrate_calc <- function(landscape, directions, cell_center,
         })
     )
 
-    tibble::tibble(level = "patch",
+    tibble::new_tibble(list(level = rep("patch", nrow(gyrate)),
                    class = as.integer(gyrate$class),
                    id = as.integer(seq_len(nrow(gyrate))),
-                   metric = "gyrate",
-                   value = as.double(gyrate$value))
+                   metric = rep("gyrate", nrow(gyrate)),
+                   value = as.double(gyrate$value)))
 
 }
