@@ -6,7 +6,7 @@ using namespace Rcpp;
 // [[Rcpp::depends(RcppArmadillo)]]
 // [[Rcpp::plugins(cpp11)]]
 
-IntegerMatrix rcpp_get_coocurrence_matrix_single(const IntegerMatrix x,
+IntegerMatrix rcpp_get_coocurrence_matrix_single(const IntegerMatrix &x,
                                                  const arma::imat directions,
                                                  const int single_class);
 #endif // GET_COOCURRENCE_MATRIX_SINGLE_H
