@@ -1,12 +1,9 @@
-context("class level lsm_c_cai_mn metric")
-
 landscapemetrics_class_landscape_value <- lsm_c_cai_mn(landscape)
 
 test_that("lsm_c_cai_mn is typestable", {
-    expect_is(lsm_c_cai_mn(landscape), "tbl_df")
-    expect_is(lsm_c_cai_mn(landscape_stack), "tbl_df")
-    expect_is(lsm_c_cai_mn(landscape_brick), "tbl_df")
-    expect_is(lsm_c_cai_mn(landscape_list), "tbl_df")
+    expect_s3_class(lsm_c_cai_mn(landscape), "tbl_df")
+    expect_s3_class(lsm_c_cai_mn(landscape_stack), "tbl_df")
+    expect_s3_class(lsm_c_cai_mn(landscape_list), "tbl_df")
 })
 
 test_that("lsm_c_cai_mn returns the desired number of columns", {
