@@ -1,12 +1,9 @@
-context("landscape level lsm_l_area_mn metric")
-
 landscapemetrics_landscape_landscape_value <- lsm_l_area_mn(landscape)
 
 test_that("lsm_l_area_mn is typestable", {
-    expect_is(lsm_l_area_mn(landscape), "tbl_df")
-    expect_is(lsm_l_area_mn(landscape_stack), "tbl_df")
-    expect_is(lsm_l_area_mn(landscape_brick), "tbl_df")
-    expect_is(lsm_l_area_mn(landscape_list), "tbl_df")
+    expect_s3_class(lsm_l_area_mn(landscape), "tbl_df")
+    expect_s3_class(lsm_l_area_mn(landscape_stack), "tbl_df")
+    expect_s3_class(lsm_l_area_mn(landscape_list), "tbl_df")
 })
 
 test_that("lsm_l_area_mn returns the desired number of columns", {
