@@ -1,5 +1,3 @@
-context("patch level lsm_p_core metric")
-
 landscapemetrics_patch_landscape_value <- lsm_p_core(landscape)
 
 test_that("lsm_p_core works for a single class landscape", {
@@ -10,10 +8,9 @@ test_that("lsm_p_core works for a single class landscape", {
 })
 
 test_that("lsm_p_core is typestable", {
-    expect_is(lsm_p_core(landscape), "tbl_df")
-    expect_is(lsm_p_core(landscape_stack), "tbl_df")
-    expect_is(lsm_p_core(landscape_brick), "tbl_df")
-    expect_is(lsm_p_core(landscape_list), "tbl_df")
+    expect_s3_class(lsm_p_core(landscape), "tbl_df")
+    expect_s3_class(lsm_p_core(landscape_stack), "tbl_df")
+    expect_s3_class(lsm_p_core(landscape_list), "tbl_df")
 })
 
 test_that("lsm_p_core returns the desired number of columns", {
@@ -30,5 +27,16 @@ test_that("lsm_p_core returns in every column the correct type", {
 })
 
 test_that("lsm_p_core can set edge depth typestable", {
-    expect_is(lsm_p_core(landscape, edge_depth = 3), "tbl_df")
+    expect_s3_class(lsm_p_core(landscape, edge_depth = 3), "tbl_df")
+})
+
+test_that("lsm_p_core equals FRAGSTATS", {
+    lsm_landscape <- lsm_p_core(landscape) |> dplyr::pull(value)
+    lsm_augusta <- lsm_p_core(augusta_nlcd) |> dplyr::pull(value)
+
+    fs_landscape <- dplyr::filter(fragstats_patch, LID == "landscape", metric == "core") |> dplyr::pull(value)
+    fs_augusta <- dplyr::filter(fragstats_patch, LID == "augusta_nlcd", metric == "core") |> dplyr::pull(value)
+
+    expect_true(test_correlation(obs = lsm_landscape, exp = fs_landscape, tolerance = tol_cor))
+    expect_true(test_correlation(obs = lsm_augusta, exp = fs_augusta, tolerance = tol_cor))
 })
